yakumo.keystone.v2.user.Resource

Package yakumo :: Package keystone :: Package v2 :: Module user :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for users on Identity V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, username=`'``__UNDEF__``'`, password=`'``__UNDEF__``'`, email=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) update properties of a user | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, username=`'``__UNDEF__``'`, password=`'``__UNDEF__``'`, email=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
update properties of a user Parameters: `name` (str) - User account `username` (str) - Full name `password` (str) - Password `email` (str) - E-mail address `project` (yakumo.keystone.v2.project.Resource) - Project `is_enabled` (str) - Whether the user is enabled or not Returns: None Overrides: base.Resource.update